@@ -122,11 +122,6 @@ check_dep_version <- function(dep_name, dep_ver = NA, dep_compare = NA) {
   return(TRUE)
 }
 
-is_installed <- function(pkg, version = 0) {
-  installed_version <- tryCatch(utils::packageVersion(pkg),
-                                error = function(e) NA)
-  !is.na(installed_version) && installed_version >= version
-}
 
 parse_deps <- function(string) {
   if (is.null(string)) return()
@@ -192,24 +187,6 @@ can_overwrite <- function(path) {
   }
 }
 
-github_info <- function(path = ".", remote_name = NULL) {
-  if (!uses_github(path)) {
-    return(github_dummy)
-  }
-
-  r <- git2r::repository(path, discover = TRUE)
-  r_remote_urls <- grep("github", remote_urls(r), value = TRUE)
-
-  if (!is.null(remote_name) && !remote_name %in% names(r_remote_urls)) {
-    stop("no github-related remote named ", remote_name, " found")
-  }
-
-  remote_name <- c(remote_name, "origin", names(r_remote_urls))
-  x <- r_remote_urls[remote_name]
-  x <- x[!is.na(x)][1]
-
-  github_remote_parse(x)
-}
 
 add_desc_package <- function(pkg = ".", field, name) {
   pkg <- as.package(pkg)
@@ -235,47 +212,6 @@ add_desc_package <- function(pkg = ".", field, name) {
   invisible(changed)
 }
 
-github_remote_parse <- function(x) {
-  if (length(x) == 0) return(github_dummy)
-  if (!grepl("github", x)) return(github_dummy)
-
-  if (grepl("^(https|git)", x)) {
-    re <- "github[^/:]*[/:]([^/]+)/(.*?)(?:\\.git)?$"
-  } else {
-    stop("Unknown GitHub repo format", call. = FALSE)
-  }
-
-  m <- regexec(re, x)
-  match <- regmatches(x, m)[[1]]
-  list(
-    username = match[2],
-    repo = match[3],
-    fullname = paste0(match[2], "/", match[3])
-  )
-}
-
-uses_git <- function(path = ".") {
-  !is.null(git2r::discover_repository(path, ceiling = 0))
-}
-
-github_dummy <- list(username = "<USERNAME>", repo = "<REPO>",
-                     fullname = "<USERNAME>/<REPO>")
-
-remote_urls <- function(r) {
-  remotes <- git2r::remotes(r)
-  stats::setNames(git2r::remote_url(r, remotes), remotes)
-}
-
-uses_github <- function(path = ".") {
-  if (!uses_git(path)) {
-    return(FALSE)
-  }
-
-  r <- git2r::repository(path, discover = TRUE)
-  r_remote_urls <- git2r::remote_url(r)
-
-  any(grepl("github", r_remote_urls))
-}
 
 read_dcf <- function(path) {
   fields <- colnames(read.dcf(path))
