@@ -5,9 +5,8 @@ packager::create(path, fakemake = "check")
 
 ## -----------------------------------------------------------------------------
 list.files(path, recursive = FALSE)
-r <- git2r::repository(path)
-summary(r)
-git2r::status(r)
+gert::git_status(repo = path)
+gert::git_log(repo = path)
 
 
 ## -----------------------------------------------------------------------------
@@ -67,9 +66,8 @@ cat(captured, sep = "\n")
 
 
 ## -----------------------------------------------------------------------------
-r <- git2r::repository(path)
-summary(r)
-git2r::status(r)
+gert::git_status(repo = path)
+gert::git_log(repo = path)
 
 
 ## -----------------------------------------------------------------------------
@@ -89,18 +87,14 @@ suppressMessages(withr::with_dir(path,
 
 
 ## -----------------------------------------------------------------------------
-cat(git2r::diff(r, as_char = TRUE, path = file.path(".Rbuildignore")))
-
-
-## -----------------------------------------------------------------------------
-git2r::status(r)
-cat(diff(r, as_char = TRUE, path = ".Rbuildignore"))
+gert::git_status(repo = path)
+git_diff(x = ".Rbuildignore", path = path)
 
 
 ## -----------------------------------------------------------------------------
 withr::with_dir(path, packager::git_add_commit(path = ".", untracked = TRUE,
                                                message = "make build"))
-git2r::status(r)
+gert::git_status(repo = path)
 
 
 ## -----------------------------------------------------------------------------
@@ -110,7 +104,7 @@ suppressMessages(withr::with_dir(path,
 
 
 ## -----------------------------------------------------------------------------
-git2r::status(r)
+gert::git_status(repo = path)
 
 
 ## -----------------------------------------------------------------------------
@@ -141,7 +135,7 @@ try(packager::submit(path))
 ## -----------------------------------------------------------------------------
 packager::git_add_commit(path = path, untracked = TRUE, 
                          message = "prepare for CRAN")
-git2r::status(r)
+gert::git_status(repo = path)
 
 
 
